@@ -18,22 +18,19 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "ksudoku_logging.h"
 #include "renderer.h"
 
+#include <QDebug>
+#include <QPainter>
+#include <QPixmap>
 #include <QSvgRenderer>
-#include <KStandardDirs>
-#include <kpixmapcache.h>
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgametheme.h>
 
 #include "settings.h"
 
-#include <QPixmap>
-#include <QPainter>
-
-#include <QtDebug>
-
 namespace ksudoku {
 
 Renderer* Renderer::instance() {
@@ -43,12 +40,11 @@ Renderer* Renderer::instance() {
 	
 Renderer::Renderer() {
 	m_renderer = new QSvgRenderer();
-	m_cache = new KPixmapCache("ksudoku-cache");
-	m_cache->setCacheLimit(3*1024);
+	m_cache = new KImageCache(QStringLiteral("ksudoku-cache"), 3*1024);
 	m_mathdokuStyle = false;
 	
 	if(!loadTheme(Settings::theme()))
-		kDebug() << "Failed to load any game theme!";
+		qCDebug(KSudokuLog) << "Failed to load any game theme!";
 }
 
 Renderer::~Renderer() {
@@ -60,7 +56,7 @@ bool Renderer::loadTheme(const QString& themeName) {
 	bool discardCache = !m_currentTheme.isEmpty();
 	
 	if(!m_currentTheme.isEmpty() && m_currentTheme == themeName) {
-		kDebug() << "Notice: loading the same theme";
+		qCDebug(KSudokuLog) << "Notice: loading the same theme";
 		return true; // this is not an error
 	}
 	
@@ -68,8 +64,8 @@ bool Renderer::loadTheme(const QString& themeName) {
 	
 	KGameTheme theme;
 	if(themeName.isEmpty() || !theme.load(themeName)) {
-		kDebug()<< "Failed to load theme" << Settings::theme();
-		kDebug() << "Trying to load default";
+		qCDebug(KSudokuLog) << "Failed to load theme" << Settings::theme();
+		qCDebug(KSudokuLog) << "Trying to load default";
 		if(!theme.loadDefault())
 			return false;
 		
@@ -78,13 +74,13 @@ bool Renderer::loadTheme(const QString& themeName) {
 	}
 	
 	bool res = m_renderer->load(theme.graphics());
-	kDebug() << "loading" << theme.graphics();
+	qCDebug(KSudokuLog) << "loading" << theme.graphics();
 	if(!res)
 		return false;
 	
 	if(discardCache) {
-		kDebug() << "discarding cache";
-		m_cache->discard();
+		qCDebug(KSudokuLog) << "discarding cache";
+		m_cache->clear();
 	}
 	
 	fillNameHashes();
@@ -148,14 +144,14 @@ QPixmap Renderer::renderBackground(const QSize& size) const {
 
 	QPixmap pix;
 	QString cacheName = QString("background_%1x%2").arg(size.width()).arg(size.height());
-	if(!m_cache->find(cacheName, pix))
+	if(!m_cache->findPixmap(cacheName, &pix))
 	{
 		pix = QPixmap(size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
 		m_renderer->render(&p, "background");
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 	return pix;
 }
@@ -184,7 +180,7 @@ QPixmap Renderer::renderSpecial(SpecialType type, int size) const {
 	
 	QString cacheName = QString("special_%1_%2").arg(m_specialNames[type]).arg(size);
 	QPixmap pix;
-	if(!m_cache->find(cacheName, pix)) {
+	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
@@ -198,7 +194,7 @@ QPixmap Renderer::renderSpecial(SpecialType type, int size) const {
 		
 		m_renderer->render(&p, m_specialNames[type], r);
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 
 	return pix;
@@ -216,7 +212,7 @@ QPixmap Renderer::renderSymbol(int symbol, int size, int max, SymbolType type) c
 
 	QString cacheName = QString("%1_%2_%3_%4").arg(set).arg(symbol).arg(size).arg(type);
 	QPixmap pix;
-	if(!m_cache->find(cacheName, pix)) {
+	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
@@ -247,7 +243,7 @@ QPixmap Renderer::renderSymbol(int symbol, int size, int max, SymbolType type) c
 				break;
 		}
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 
 	return pix;
@@ -300,7 +296,7 @@ QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 	QString groupName = QString("markers%1").arg(range);
 	QString cacheName = QString("%1_%2_%3").arg(groupName).arg(symbol).arg(size);
 	QPixmap pix;
-	if(!m_cache->find(cacheName, pix)) {
+	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
@@ -316,7 +312,7 @@ QPixmap Renderer::renderMarker(int symbol, int range, int size) const {
 
 		m_renderer->render(&p, QString("%1_%2").arg(set).arg(symbol), r);
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 
 	return pix;
@@ -383,7 +379,7 @@ QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 	
 	QString cacheName = QString("contour_%1_%2_%3").arg(m_borderTypes[type]).arg(m_borderNames[border]).arg(size);
 	QPixmap pix;
-	if(!m_cache->find(cacheName, pix)) {
+	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
@@ -397,7 +393,7 @@ QPixmap Renderer::renderBorder(int border, GroupTypes type, int size) const {
 		
 		m_renderer->render(&p, QString("%1_%2").arg(m_borderTypes[type]).arg(m_borderNames[border]), r);
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 
 	return pix;
@@ -408,7 +404,7 @@ QPixmap Renderer::renderSpecial3D(SpecialType type, int size) const {
 
 	QString cacheName = QString("special_%1_%2").arg(m_special3dNames[type]).arg(size);
 	QPixmap pix;
-	if(!m_cache->find(cacheName, pix)) {
+	if(!m_cache->findPixmap(cacheName, &pix)) {
 		pix = QPixmap(size, size);
 		pix.fill(Qt::transparent);
 		QPainter p(&pix);
@@ -422,7 +418,7 @@ QPixmap Renderer::renderSpecial3D(SpecialType type, int size) const {
 		
 		m_renderer->render(&p, m_special3dNames[type], r);
 		p.end();
-		m_cache->insert(cacheName, pix);
+		m_cache->insertPixmap(cacheName, pix);
 	}
 
 	return pix;
